@@ -68,14 +68,9 @@ impl PluginManager {
 
     /// Calls the `on_request` function on every plugin.
     /// If a plugin overrides the response, this is immediately returned.
-    pub fn on_request(
-        &self,
-        request: &mut Request,
-        state: Arc<AppState>,
-        directory: &str,
-    ) -> Option<Response> {
+    pub fn on_request(&self, request: &mut Request, state: Arc<AppState>) -> Option<Response> {
         for plugin in &self.plugins {
-            if let Some(response) = plugin.on_request(request, state.clone(), directory) {
+            if let Some(response) = plugin.on_request(request, state.clone()) {
                 return Some(response);
             }
         }
