@@ -36,12 +36,7 @@ pub trait Plugin: Any + Send + Sync + Debug {
     /// Called when a request is received but before it is processed. May modify the request in-place.
     /// Should return `None` to indicate that Humphrey should process the request,
     ///   or the plugin should process the request itself and return `Some(response)`.
-    fn on_request(
-        &self,
-        request: &mut Request,
-        state: Arc<AppState>,
-        directory: &str,
-    ) -> Option<Response> {
+    fn on_request(&self, request: &mut Request, state: Arc<AppState>) -> Option<Response> {
         None
     }
 
